@@ -30,14 +30,14 @@ class Algo:
             self.wallet = wallet
             self.positions = positions
 
-    def __init__(self, data_path, data_source, GUID, wallet, tickers, tick_period):
+    def __init__(self, data_path, data_source, GUID, config):
         self.log = AlgoLogger(data_path=data_path)
         self.log.set_name(GUID)
         self.data_source = data_source
         self.GUID = GUID
-        self.wallet = wallet
-        self.tickers = tickers
-        self.tick_period = tick_period
+        self.wallet = float(config["start_wallet"])
+        self.tickers = config["tickers"].split(",")
+        self.tick_period = int(config["tick_period"])
         self.test_mode = True
         self.positions = {}
         for t in self.tickers:
@@ -132,6 +132,9 @@ class Algo:
         self.save_algo()
         self.log.output()
 
+    def print_details(self):
+        return ""
+
 class AlgoBb(Algo):
     
     def __init__ (self, data_path, data_source,  GUID, wallet, ticker, tick_period, algo_params):
@@ -372,27 +375,30 @@ class AlgoRsi(Algo):
 
 class AlgoRsiBb(Algo):
         
-    def __init__ (self, data_path, data_source, GUID,  wallet, tickers, tick_period, algo_params):
-        super().__init__(data_path, data_source, GUID,  wallet, tickers, tick_period)
-        self.points = int(algo_params[0])
-        self.stddev = float(algo_params[1])
-        self.rsi_high = float(algo_params[2])
-        self.rsi_low = float(algo_params[3])
-        self.buy_percent = float(algo_params[4])
-        self.sell_percent = float(algo_params[5])
+    def __init__ (self, data_path, data_source, GUID, config):
+        super().__init__(data_path, data_source, GUID,  config)
+        self.points = int(config["data_points"])
+        self.stddev = float(config["std_dev"])
+        self.rsi_high = float(config["rsi_high"])
+        self.rsi_low = float(config["rsi_low"])
+        self.buy_percent = float(config["buy_percent"])
+        self.sell_percent = float(config["sell_percent"])
         self.bollinger_indicator = {}
         self.buy_qty = {}
         self.init_buy_price = {}
         self.init_buy = {}
         self.prev_rsi = {}
-        for t in tickers:
-            self.buy_qty[t] = int( (wallet*self.buy_percent) / float(self._get_last_trade(t)))
+        for t in self.tickers:
+            self.buy_qty[t] = int( (self.wallet*self.buy_percent) / float(self._get_last_trade(t)))
             if self.buy_qty[t] < 1:
                 self.buy_qty[t] = 1
             self.init_buy_price[t] = 0
             self.init_buy[t] = True
             self.bollinger_indicator[t] = "Middle"
 
+    def print_details(self):
+        return "{},{},{},{},{}".format(self.stddev, self.rsi_high, self.rsi_low, self.buy_percent, self.sell_percent)
+
     def run(self, return_dict):
         super().run()
         trades = {}
